@@ -4,10 +4,15 @@ use image::{ImageError, Rgb, RgbImage};
 
 use std::path::Path;
 
+enum Target<'a> {
+    File(&'a Path),
+    Buffer,
+}
+
 /// The backend that drawing a bitmap
 pub struct BitMapBackend<'a> {
     /// The path to the image
-    path: &'a Path,
+    target: Target<'a>,
     /// The image object
     img: RgbImage,
     /// Flag indicates if the bitmap has been saved
@@ -18,11 +23,34 @@ impl<'a> BitMapBackend<'a> {
     /// Create a new bitmap backend
     pub fn new<T: AsRef<Path> + ?Sized>(path: &'a T, dimension: (u32, u32)) -> Self {
         Self {
-            path: path.as_ref(),
+            target: Target::File(path.as_ref()),
             img: RgbImage::new(dimension.0, dimension.1),
             saved: false,
         }
     }
+
+    /// Create a new bitmap backend which only lives in-memory
+    pub fn in_memory(dimension: (u32, u32)) -> Self {
+        Self {
+            target: Target::Buffer,
+            img: RgbImage::new(dimension.0, dimension.1),
+            saved: false,
+        }
+    }
+
+    /// Try to convert the bitmap backend into the memory buffer
+    /// If the backend is backed with a file, this function won't make
+    /// the conversion and return the backend object back as the error
+    pub fn try_into_buffer(mut self) -> Result<Vec<u8>, Self> {
+        match self.target {
+            Target::File(_) => Err(self),
+            Target::Buffer => {
+                let mut actual_img = RgbImage::new(1, 1);
+                std::mem::swap(&mut actual_img, &mut self.img);
+                Ok(actual_img.into_raw())
+            }
+        }
+    }
 }
 
 impl<'a> DrawingBackend for BitMapBackend<'a> {
@@ -37,11 +65,16 @@ impl<'a> DrawingBackend for BitMapBackend<'a> {
     }
 
     fn present(&mut self) -> Result<(), DrawingErrorKind<ImageError>> {
-        self.img
-            .save(&self.path)
-            .map_err(|x| DrawingErrorKind::DrawingError(ImageError::IoError(x)))?;
-        self.saved = true;
-        Ok(())
+        match self.target {
+            Target::File(path) => {
+                self.img
+                    .save(&path)
+                    .map_err(|x| DrawingErrorKind::DrawingError(ImageError::IoError(x)))?;
+                self.saved = true;
+                Ok(())
+            }
+            Target::Buffer => Ok(()),
+        }
     }
 
     fn draw_pixel(
