@@ -12,7 +12,9 @@
     <img style="display: inline! important" src="https://img.shields.io/badge/docs-development-lightgrey.svg"></img>
 </a>
 
-*Please note: This library is in a very early stage. I am trying my best to stabilize the APIs and improving the overall quality. APIs may change at this time.*
+<a href="https://travis-ci.org/38/plotters">
+    <img style="display: inline! important" src="https://travis-ci.org/38/plotters.svg?branch=master"></img>
+</a>
 
 Plotters is drawing library designed for rendering figures, plots, and charts, in pure rust. Plotters supports various types of backends,
 including bitmap, vector graph, piston window and WebAssembly.
@@ -20,8 +22,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 ## Gallery
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/sample.png">
-        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/sample.png" class="galleryItem"></img>
+    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/sample.png">
+        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/sample.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Multiple Plot
@@ -30,8 +32,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/stock.png">
-        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/stock.png" class="galleryItem"></img>
+    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/stock.png">
+        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/stock.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Candlestick Plot
@@ -40,8 +42,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/histogram.png">
-        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/histogram.png" class="galleryItem"></img>
+    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/histogram.png">
+        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/histogram.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
        Histogram
@@ -50,8 +52,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/0.png">
-        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/0.png" class="galleryItem"></img>
+    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/0.png">
+        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/0.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Simple Chart
@@ -59,8 +61,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/mandelbrot.png">
-        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/mandelbrot.png" class="galleryItem"></img>
+    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/mandelbrot.png">
+        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/mandelbrot.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Mandelbrot set
@@ -70,8 +72,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/evcxr_animation.gif">
-        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/evcxr_animation.gif" class="galleryItem"></img>
+    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/evcxr_animation.gif">
+        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/evcxr_animation.gif" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Jupyter Support
@@ -79,8 +81,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/plotters-piston.gif">
-        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/plotters-piston.gif" class="galleryItem"></img>
+    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/plotters-piston.gif">
+        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/plotters-piston.gif" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Realtime Rendering
@@ -88,7 +90,8 @@ including bitmap, vector graph, piston window and WebAssembly.
     </div>
 </div>
 
-## Table of Content
+
+## Table of Contents
   * [Gallery](#gallery)
   * [Quick Start](#quick-start)
   * [Trying with Jupyter evcxr Kernel Interactively](#trying-with-jupyter-evcxr-kernel-interactively)
@@ -105,14 +108,12 @@ including bitmap, vector graph, piston window and WebAssembly.
     + [Development Version](#development-version)
     + [Reducing Depending Libraries && Turning Off Backends](#reducing-depending-libraries----turning-off-backends)
 
-
-
 ## Quick Start
 
 To use Plotters, you can simply add Plotters into your `Cargo.toml`
 ```toml
 [depedencies]
-plotters = "^0.2.0"
+plotters = "^0.2.1"
 ```
 
 And the following code draws a quadratic function. `src/main.rs`,
@@ -120,7 +121,7 @@ And the following code draws a quadratic function. `src/main.rs`,
 ```rust
 use plotters::prelude::*;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let root = BitMapBackend::new("examples/outputs/0.png", (640, 480)).into_drawing_area();
+    let root = BitMapBackend::new("plotters-doc-data/0.png", (640, 480)).into_drawing_area();
     root.fill(&White)?;
     let mut chart = ChartBuilder::on(&root)
         .caption("y=x^2", ("Arial", 50).into_font())
@@ -147,7 +148,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/0.png)
+![](https://raw.githubusercontent.com/38/plotters-doc-data/master/0.png)
 
 
 ## Trying with Jupyter evcxr Kernel Interactively
@@ -189,7 +190,7 @@ let figure = evcxr_figure((640, 480), |root| {
 figure
 ```
 
-<img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/evcxr_animation.gif" width="450px"></img>
+<img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/evcxr_animation.gif" width="450px"></img>
 
 ## Plotting in Rust
 
@@ -239,7 +240,7 @@ Plotters can use different drawing backends, including SVG, BitMap, and even rea
 use plotters::prelude::*;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
     // Create a 800*600 bitmap and start drawing
-    let mut backend = BitMapBackend::new("examples/outputs/1.png", (300, 200));
+    let mut backend = BitMapBackend::new("plotters-doc-data/1.png", (300, 200));
     // And if we want SVG backend
     // let backend = SVGBackend::new("output.svg", (800, 600));
     backend.draw_rect((50, 50), (200, 150), &Red, true)?;
@@ -247,7 +248,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/1.png)
+![](https://raw.githubusercontent.com/38/plotters-doc-data/master/1.png)
 
 ### Drawing Area
 Plotters uses a concept called drawing area for layout purpose.
@@ -260,7 +261,7 @@ Besides that, the drawing area also allows the customized coordinate system, by
 use plotters::prelude::*;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
     let root_drawing_area =
-        BitMapBackend::new("examples/outputs/2.png", (300, 200)).into_drawing_area();
+        BitMapBackend::new("plotters-doc-data/2.png", (300, 200)).into_drawing_area();
     // And we can split the drawing area into 3x3 grid
     let child_drawing_areas = root_drawing_area.split_evenly((3, 3));
     // Then we fill the drawing area with different color
@@ -271,7 +272,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/2.png)
+![](https://raw.githubusercontent.com/38/plotters-doc-data/master/2.png)
 
 ### Elements
 
@@ -286,7 +287,7 @@ To learn more about the element system, please read the [element module document
 ```rust
 use plotters::prelude::*;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let root = BitMapBackend::new("examples/outputs/3.png", (300, 200)).into_drawing_area();
+    let root = BitMapBackend::new("plotters-doc-data/3.png", (300, 200)).into_drawing_area();
     root.fill(&White)?;
     // Draw an circle on the drawing area
     root.draw(&Circle::new(
@@ -298,7 +299,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/3.png)
+![](https://raw.githubusercontent.com/38/plotters-doc-data/master/3.png)
 
 ### Composable Elements
 
@@ -312,7 +313,7 @@ For example, we can have an element which includes a dot and its coordinate.
 use plotters::prelude::*;
 
 fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let root = BitMapBackend::new("examples/outputs/4.png", (640, 480)).into_drawing_area();
+    let root = BitMapBackend::new("plotters-doc-data/4.png", (640, 480)).into_drawing_area();
 
     root.fill(&RGBColor(240, 200, 200))?;
 
@@ -335,7 +336,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/4.png)
+![](https://raw.githubusercontent.com/38/plotters-doc-data/master/4.png)
 
 ### Chart Context
 
@@ -347,7 +348,7 @@ of the chart context object.
 ```rust
 use plotters::prelude::*;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let root = BitMapBackend::new("examples/outputs/5.png", (640, 480)).into_drawing_area();
+    let root = BitMapBackend::new("plotters-doc-data/5.png", (640, 480)).into_drawing_area();
     root.fill(&White);
     let root = root.margin(10, 10, 10, 10);
     // After this point, we should be able to draw construct a chart context
@@ -390,7 +391,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/5.png)
+![](https://raw.githubusercontent.com/38/plotters-doc-data/master/5.png)
 
 ## Misc
 
